@@ -25,6 +25,7 @@ pub use xmas_elf::sections::Rela;
 pub use xmas_elf::symbol_table::{Entry, Entry64};
 pub use xmas_elf::{P32, P64};
 
+/// An iterator over [`ProgramHeader`] whose type is `LOAD`.
 pub type LoadableHeaders<'a, 'b> = Filter<ProgramIter<'a, 'b>, fn(&ProgramHeader) -> bool>;
 pub type PAddr = u64;
 pub type VAddr = u64;
@@ -438,27 +439,7 @@ impl<'s> ElfBinary<'s> {
     pub fn load(&self, loader: &mut dyn ElfLoader) -> Result<(), ElfLoaderErr> {
         self.is_loadable()?;
 
-        // Trying to determine loadeable headers
-        fn select_load(&pheader: &ProgramHeader) -> bool {
-            if let Ph64(header) = pheader {
-                header
-                    .get_type()
-                    .map(|typ| typ == Type::Load)
-                    .unwrap_or(false)
-            } else {
-                false
-            }
-        }
-
-        // Create an iterator (well filter really) that has all loadeable
-        // headers and pass it to the loader
-        // TODO: This is pretty ugly, maybe we can do something with impl Trait?
-        // https://stackoverflow.com/questions/27535289/what-is-the-correct-way-to-return-an-iterator-or-any-other-trait
-        let load_iter = self
-            .file
-            .program_iter()
-            .filter(select_load as fn(&ProgramHeader) -> bool);
-        loader.allocate(load_iter)?;
+        loader.allocate(self.iter_loadable_headers())?;
 
         // Load all headers
         for p in self.file.program_iter() {
@@ -496,6 +477,26 @@ impl<'s> ElfBinary<'s> {
 
         Ok(())
     }
+
+    fn iter_loadable_headers(&self) -> LoadableHeaders {
+        // Trying to determine loadeable headers
+        fn select_load(pheader: &ProgramHeader) -> bool {
+            if let Ph64(header) = pheader {
+                header
+                    .get_type()
+                    .map(|typ| typ == Type::Load)
+                    .unwrap_or(false)
+            } else {
+                false
+            }
+        }
+
+        // Create an iterator (well filter really) that has all loadeable
+        // headers and pass it to the loader
+        // TODO: This is pretty ugly, maybe we can do something with impl Trait?
+        // https://stackoverflow.com/questions/27535289/what-is-the-correct-way-to-return-an-iterator-or-any-other-trait
+        self.file.program_iter().filter(select_load)
+    }
 }
 
 #[cfg(test)]
@@ -702,3 +703,15 @@ mod test {
             .is_some());
     }
 }
+
+#[cfg(doctest)]
+mod test_readme {
+    macro_rules! external_doc_test {
+        ($x:expr) => {
+            #[doc = $x]
+            extern "C" {}
+        };
+    }
+
+    external_doc_test!(include_str!("../README.md"));
+}
